@@ -5,9 +5,9 @@
     .module('horizon.dashboard.project.vitrage')
     .controller('AlarmListController', AlarmListController);
 
-  AlarmListController.$inject = ['$scope', 'modalSrv', 'vitrageTopologySrv', '$interval', '$location'];
+  AlarmListController.$inject = ['$scope', 'modalSrv', 'vitrageTopologySrv', 'timeSrv', '$interval', '$location'];
 
-  function AlarmListController($scope, modalSrv, vitrageTopologySrv, $interval, $location) {
+  function AlarmListController($scope, modalSrv, vitrageTopologySrv, timeSrv, $interval, $location) {
     var alarmList = this;
     var LIMIT = horizon.cookies.get('API_RESULT_PAGE_SIZE') || 20;
     var filterTimeout;
@@ -28,6 +28,8 @@
     alarmList.checkboxAutoRefresh = true;
     $scope.STATIC_URL = STATIC_URL;
     alarmList.format = 'dd-MMMM-yyyy';
+    alarmList.timezone = timeSrv.getHorizonTimezone();
+    alarmList.dateFormat = timeSrv.longDateFormat;
     alarmList.dateOptions = {
       dateDisabled: false,
       formatYear: 'yy',
@@ -58,6 +60,15 @@
       opened: false
     };
 
+    alarmList.autoRefreshChanged = function () {
+      if (alarmList.checkboxAutoRefresh && alarmList.radioModel !== 'historyAlarms') {
+        startCollectData();
+      } else {
+        stopCollectData();
+      }
+    };
+
+
     alarmList.getHistoryData = function (nextPrev) {
       if (nextPrev === 'next' && !alarmList.nextEnabled) {
         return;
@@ -71,6 +82,8 @@
       };
 
       if (alarmList.radioModel === 'historyAlarms') {
+        alarmList.toDateTime = new Date();
+        alarmList.toDateTime.setMilliseconds(0);
         config.start = alarmList.fromDateTime;
         config.end = alarmList.toDateTime;
       }
@@ -100,9 +113,12 @@
 
 
       if (alarmList.radioModel === 'historyAlarms') {
-        vitrageTopologySrv.getHistoryAlarms(config).then(function (result) {
+          $("#table").hide();
+          $("#spinner").show();
+          vitrageTopologySrv.getHistoryAlarms(config).then(function (result) {
           alarmList.alarms = result.data;
-
+          $("#spinner").hide();
+          $("#table").show();
           alarmList.nextEnabled = result.data.length === LIMIT;
           alarmList.prevEnabled = true;
         });
@@ -119,6 +135,18 @@
 
     alarmList.getHistoryData();
 
+    function startCollectData() {
+      if (angular.isDefined(alarmList.alarmInterval)) return;
+      alarmList.alarmInterval = alarmList.$interval(alarmList.getHistoryData,10000);
+    }
+
+    function stopCollectData() {
+      if (angular.isDefined(alarmList.alarmInterval)) {
+        alarmList.$interval.cancel(alarmList.alarmInterval);
+        alarmList.alarmInterval = undefined;
+      }
+    }
+
     alarmList.sortBy = function (fieldName) {
       if (fieldName === alarmList.sortByFieldName) {
         alarmList.sortOrder = alarmList.sortOrder === 'asc' ? 'desc' : 'asc';
